<?php


namespace Controller;

use Exception\CustomException;
use Traits\TResponse;
use Util\InstanceProvider;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Attachment
{
    use TResponse;

    /**
     * @var \Service\Attachment
     */
    private $attachmentService;

    public function __construct(\Service\Attachment $attachmentService) {
        $this->attachmentService = $attachmentService;
    }

    public function downLoadAttachment(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $commentId = null;
            if(!empty($param['ID'])){
                $commentId = $param['ID'];
            }
            $filename  = null;
            if(!empty($param['FILENAME'])){
                $filename = $param['FILENAME'];
            }
            $this->attachmentService->downLoadAttachment($commentId);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downLoadAttachmentGEP(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $commentId = null;
            if(!empty($param['ID'])){
                $commentId = $param['ID'];
            }
            $filename  = null;
            if(!empty($param['FILENAME'])){
                $filename = $param['FILENAME'];
            }
            $this->attachmentService->downLoadAttachmentGEP($filename);
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function newCallAttachment(Request $request, Response $response) {
        try {
            $row = $request->getParameters();
            $callType           = isset($row["CALL_TYPE"]) ? $row["CALL_TYPE"] : null;
            if($callType == \Service\Call::TYPE_ISSUE){
                InstanceProvider::getFileUploaderServe()->uploadFilesInRow($row, 'DOCUMENT', 'PmDevOps/Projects');
            }
            $subject            = isset($row["SUBJECT"]) ? $row["SUBJECT"] : '';
            $description        = empty($row['DESCRIPTION']) ? null : $row['DESCRIPTION'];
            $supportCallId      = empty($row['CALL_ID']) ? null : $row['CALL_ID'];
            $createdBy          = empty($row['CREATED_BY']) ? null : $row['CREATED_BY'];
            $document           = empty($row['DOCUMENT']) ? null : $row['DOCUMENT'];
            $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
            $this->attachmentService->newCallAttachment($supportCallId, $description, $document, $createdBy, $callRelationship, $subject, $callType);
        } catch (CustomException $e) {
            $response->setError(\Util\Utilities::getErrorObjectFromException($e));
        }
    }

    public function deleteProductCallAttachments(Request $request, Response $response) {
        try {
            $rows = $request->getParameters();
            foreach ($rows as $row) {
                $id = $row['ID'];
                $dir = isset($row['FILENAME'])?$row['FILENAME']:null;
                $callRelationship   = empty($row['CALL_RELATIONSHIP']) ? null : $row['CALL_RELATIONSHIP'];
                $callType           = isset($row["CALL_TYPE"]) ? $row["CALL_TYPE"] : null;
                $isIssue = $callType == \Service\Call::TYPE_ISSUE;
                $this->attachmentService->deleteProductCallAttachments($id,$isIssue,$dir);
            }

        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }

    }
}
