<?php

namespace Service;

use Exception\CustomException;
use Teknisa\Model\Geral\Entities\Operador;
use Util\InstanceProvider;
use Util\Utilities;
use Doctrine\ORM\EntityManager;
use \Zeedhi\DevOps\Model\Projectmanagement\Entities;

class Comment
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var Utilities
     */
    private $environment;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager  = $entityManager;
        $this->environment    = InstanceProvider::getEnvironment();


    }

    public function saveCallComment($description, $callRelationship , $callType, $subject = 'Adicionou novo comentário')
    {
        $commentDate ='';
        $intranetIntegrationService = InstanceProvider::getService()->getINTRANETIntegration();
        $connection = $this->entityManager->getConnection();
        try {

            $connection->beginTransaction();
            $createdBy = $this->environment->getCurrentCdoperador();

            /** @var Operador $commenter */
            $commenter = InstanceProvider::getRepository()->getOperador()->findOneBy(array('cdoperador' => $this->environment->getCurrentCdoperador()));

            if($callType == Call::TYPE_ISSUE) {
                $this->pmIntegrationService->saveCommentOnIssueByProductCallComment($callRelationship, $description, $createdBy, $commenter->getCdCliente());
            } else if($callType == Call::TYPE_RICH_CLIENT) {

                $nrorgId = $this->environment->getCurrentOrganizationId();
                $commentDate = $intranetIntegrationService->saveCommentOnSolicitacaoByProductCallComment($callRelationship, $subject, $description, $createdBy,$nrorgId);

                $comments = InstanceProvider::getRepository()->getCallComments()->getProductCallCommentsFromSolicitacao($callRelationship,null,true);
                if($comments && !empty($comments[1])){
                    $newFilename = $comments[0]['ORDERBY'];
                    $filename = $comments[1]['ORDERBY'];
                    $cdClienteBase = \Util\Utilities::getCdClienteBase();
                    $fileDir = $intranetIntegrationService->basicIntranetFileDir;
                    $folders    = InstanceProvider::getRepository()->getCallAttachment()->getAllAttachmentsFolder($callRelationship,
                        $fileDir, $cdClienteBase, true, $filename);

                    if($folders){
                        foreach($folders as $folder){
                            $newFolder = str_replace($filename, $newFilename, $folder['DIR']);
                            if(file_exists($folder['DIR'])){
                                rename($folder['DIR'], $newFolder);
                            }
                        }
                    }
                }
            }

            $connection->commit();

            return $commentDate;
        } catch(\Exception $e) {
            $connection->rollBack();
            throw new CustomException('ERR_NOT_POSSIBLE_TO_CREATE_COMMENT', 500, array( 'error' => $e->getMessage()));
        }
    }
}
